@@ -172,7 +172,7 @@ class FileHandler(object):
             if not isinstance(sheet_names, list):
                 raise ValueError("'sheet_names' %r is not a list value" % sheet_name)
 
-            self.__sheet_names = [s.lower() for s in self.sheet_names]
+            self.__sheet_names = [s.lower() for s in sheet_names]
         else:
             self.__sheet_names = list()
 
